#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 req
version:              3.9.1
visibility:           public
id:                   req-3.9.1-3qHrmh5ZnR0F6stCJEaHVd
key:                  req-3.9.1-3qHrmh5ZnR0F6stCJEaHVd
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  5687071af5d19b626c50e7ea28c81af7
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-8.10.5/site-local/req-3.9.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/req-3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/req-3.9.1
hs-libraries:         HSreq-3.9.1-3qHrmh5ZnR0F6stCJEaHVd
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    authenticate-oauth-1.6.0.1-85aPAq7RPWmKigOLx8bBdW base-4.14.2.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    connection-0.3.1-ADJpwCmobBsDFPJVx1SRC3 exceptions-0.10.4
    http-api-data-0.4.3-JUnrChvmGZhIDkVtiYRrjz
    http-client-0.7.8-C6JWYZrbeBCPAdb6EpQD6
    http-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    modern-uri-0.3.4.1-v472keFKueHixOvPxm7G0
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J mtl-2.2.2
    retry-0.8.1.2-CZdjYjDlI2c1IJ5AtphJdU template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

